@@ -3,7 +3,7 @@ use 5.008_001;
 use strict;
 use warnings;
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 use Module::Load;
 
@@ -127,7 +127,7 @@ sub get_multi {
 sub set {
     my ($self, $key, $value, $expire, $callback) = @_;
 
-    die 'set() requires key and value arguments' unless $key && $value;
+    die 'set() requires key and value arguments' if scalar(@_) < 3;
 
     my $response = $self->_set($key, $value, $expire, $callback);
 
